@@ -15,8 +15,6 @@ except ImportError:  # In case this plugin is not installed
     PYTEST_HEADER_MODULES = {}
     TESTED_VERSIONS = {}
 
-from astropy.tests.helper import enable_deprecations_as_exceptions
-
 # We do this to pick up the test header report even when using LTS astropy
 try:
     from astropy.tests.pytest_plugins import pytest_report_header  # noqa
@@ -36,10 +34,6 @@ packagename = os.path.basename(os.path.dirname(__file__))
 TESTED_VERSIONS[packagename] = version
 
 
-# Comment out this line to avoid deprecation warnings being raised as
-# exceptions
-enable_deprecations_as_exceptions()
-
 # Define list of packages for which to display version numbers in the test log
 try:
     PYTEST_HEADER_MODULES['Astropy'] = 'astropy'
