@@ -10,12 +10,13 @@ from __future__ import (absolute_import, division, print_function,
 # Standard library
 from abc import ABCMeta, abstractmethod
 import datetime
+import time
 import warnings
 
 # Third-party
 from astropy.time import Time
 import astropy.units as u
-from astropy.coordinates import get_body, get_sun, get_moon, Galactic, SkyCoord
+from astropy.coordinates import get_body, get_sun, Galactic, SkyCoord
 from astropy import table
 
 import numpy as np
@@ -25,6 +26,7 @@ from numpy.lib.stride_tricks import as_strided
 from .moon import moon_illumination
 from .utils import time_grid_from_range
 from .target import get_skycoord
+from .exceptions import MissingConstraintWarning
 
 __all__ = ["AltitudeConstraint", "AirmassConstraint", "AtNightConstraint",
            "is_observable", "is_always_observable", "time_grid_from_range",
@@ -35,6 +37,12 @@ __all__ = ["AltitudeConstraint", "AirmassConstraint", "AtNightConstraint",
            "observability_table", "months_observable", "max_best_rescale",
            "min_best_rescale", "PhaseConstraint", "is_event_observable"]
 
+_current_year = time.localtime().tm_year  # needed for backward compatibility
+_current_year_time_range = Time(  # needed for backward compatibility
+    [str(_current_year) + '-01-01',
+     str(_current_year) + '-12-31']
+)
+
 
 def _make_cache_key(times, targets):
     """
@@ -346,7 +354,7 @@ class AltitudeConstraint(Constraint):
             uppermask = alt <= self.max
             return lowermask & uppermask
         else:
-            return max_best_rescale(alt, self.min, self.max)
+            return max_best_rescale(alt, self.min, self.max, greater_than_max=0)
 
 
 class AirmassConstraint(AltitudeConstraint):
@@ -542,6 +550,7 @@ class SunSeparationConstraint(Constraint):
         # by the observer.
         # 'get_sun' returns ICRS coords.
         sun = get_body('sun', times, location=observer.location)
+        targets = get_skycoord(targets)
         solar_separation = sun.separation(targets)
 
         if self.min is None and self.max is not None:
@@ -582,15 +591,12 @@ class MoonSeparationConstraint(Constraint):
         self.ephemeris = ephemeris
 
     def compute_constraint(self, times, observer, targets):
-        # removed the location argument here, which causes small <1 deg
-        # innacuracies, but it is needed until astropy PR #5897 is released
-        # which should be astropy 1.3.2
-        moon = get_moon(times,
-                        ephemeris=self.ephemeris)
+        moon = get_body("moon", times, location=observer.location, ephemeris=self.ephemeris)
         # note to future editors - the order matters here
         # moon.separation(targets) is NOT the same as targets.separation(moon)
         # the former calculates the separation in the frame of the moon coord
         # which is GCRS, and that is what we want.
+        targets = get_skycoord(targets)
         moon_separation = moon.separation(targets)
 
         if self.min is None and self.max is not None:
@@ -1086,10 +1092,11 @@ def is_event_observable(constraints, observer, target, times=None,
 
 
 def months_observable(constraints, observer, targets,
+                      time_range=_current_year_time_range,
                       time_grid_resolution=0.5*u.hour):
     """
     Determines which month the specified ``targets`` are observable for a
-    specific ``observer``, given the supplied ``constriants``.
+    specific ``observer``, given the supplied ``constraints``.
 
     Parameters
     ----------
@@ -1102,6 +1109,10 @@ def months_observable(constraints, observer, targets,
     targets : {list, `~astropy.coordinates.SkyCoord`, `~astroplan.FixedTarget`}
         Target or list of targets
 
+    time_range : `~astropy.time.Time` (optional)
+        Lower and upper bounds on time sequence
+        If ``time_range`` is not specified, defaults to current year (localtime)
+
     time_grid_resolution : `~astropy.units.Quantity` (optional)
         If ``time_range`` is specified, determine whether constraints are met
         between test times in ``time_range`` by checking constraint at
@@ -1121,14 +1132,20 @@ def months_observable(constraints, observer, targets,
     if not hasattr(constraints, '__len__'):
         constraints = [constraints]
 
-    # Calculate throughout the year of 2014 so as not to require forward
-    # extrapolation off of the IERS tables
-    time_range = Time(['2014-01-01', '2014-12-31'])
     times = time_grid_from_range(time_range, time_grid_resolution)
 
+    # If the constraints don't include AltitudeConstraint or its subclasses,
+    # warn the user that they may get months when the target is below the horizon
+    altitude_constraint_supplied = any(
+        [isinstance(constraint, AltitudeConstraint) for constraint in constraints]
+    )
+    if not altitude_constraint_supplied:
+        message = ("months_observable usually expects an AltitudeConstraint or "
+                   "AirmassConstraint to ensure targets are above horizon.")
+        warnings.warn(message, MissingConstraintWarning)
+
     # TODO: This method could be sped up a lot by dropping to the trigonometric
     # altitude calculations.
-
     applied_constraints = [constraint(observer, targets,
                                       times=times,
                                       grid_times_targets=True)
