@@ -30,7 +30,7 @@ class ObservingBlock(object):
     constraints on observations.
     """
     @u.quantity_input(duration=u.second)
-    def __init__(self, target, duration, priority, configuration={}, constraints=None):
+    def __init__(self, target, duration, priority, configuration={}, constraints=None, name=None):
         """
         Parameters
         ----------
@@ -52,12 +52,16 @@ class ObservingBlock(object):
             that constraints applicable to the entire list should go into the
             scheduler.
 
+        name : integer or str
+            User-defined name or ID.
+
         """
         self.target = target
         self.duration = duration
         self.priority = priority
         self.configuration = configuration
         self.constraints = constraints
+        self.name = name
         self.start_time = self.end_time = None
         self.observer = None
 
@@ -231,7 +235,7 @@ class Schedule(object):
     def __init__(self, start_time, end_time, constraints=None):
         """
         Parameters
-        -----------
+        ----------
         start_time : `~astropy.time.Time`
             The starting time of the schedule; the start of your
             observing window.
@@ -278,8 +282,8 @@ class Schedule(object):
                 end_times.append(slot.end.iso)
                 durations.append(slot.duration.to(u.minute).value)
                 target_names.append(slot.block.target.name)
-                ra.append(slot.block.target.ra)
-                dec.append(slot.block.target.dec)
+                ra.append(u.Quantity(slot.block.target.ra))
+                dec.append(u.Quantity(slot.block.target.dec))
                 config.append(slot.block.configuration)
             elif show_transitions and slot.block:
                 start_times.append(slot.start.iso)
@@ -300,8 +304,7 @@ class Schedule(object):
                 ra.append('')
                 dec.append('')
                 config.append('')
-        return Table([target_names, start_times, end_times, durations,
-                      u.Quantity(ra), u.Quantity(dec), config],
+        return Table([target_names, start_times, end_times, durations, ra, dec, config],
                      names=('target', 'start time (UTC)', 'end time (UTC)',
                             'duration (minutes)', 'ra', 'dec', 'configuration'))
 
@@ -428,7 +431,7 @@ class Slot(object):
     def __init__(self, start_time, end_time):
         """
         Parameters
-        -----------
+        ----------
         start_time : `~astropy.time.Time`
             The starting time of the slot
         end_time : `~astropy.time.Time`
@@ -745,7 +748,7 @@ class PriorityScheduler(Scheduler):
         score_array = scorer.create_score_array(time_resolution)
 
         # Sort the list of blocks by priority
-        sorted_indices = np.argsort(_block_priorities)
+        sorted_indices = np.argsort(_block_priorities, kind='mergesort')
 
         unscheduled_blocks = []
         # Compute the optimal observation time in priority order
@@ -763,7 +766,7 @@ class PriorityScheduler(Scheduler):
             # Select the most optimal time
 
             # calculate the number of time slots needed for this exposure
-            _stride_by = np.int(np.ceil(float(b.duration / time_resolution)))
+            _stride_by = int(np.ceil(float(b.duration / time_resolution)))
 
             # Stride the score arrays by that number
             _strided_scores = stride_array(constraint_scores, _stride_by)
@@ -783,7 +786,7 @@ class PriorityScheduler(Scheduler):
                 # does not prevent us from fitting it in.
                 # loop over valid times and see if it fits
                 # TODO: speed up by searching multiples of time resolution?
-                for idx in np.argsort(sum_scores)[::-1]:
+                for idx in np.argsort(-sum_scores, kind='mergesort'):
                     if sum_scores[idx] <= 0.0:
                         # we've run through all optimal blocks
                         _is_scheduled = False
@@ -807,7 +810,7 @@ class PriorityScheduler(Scheduler):
 
     def attempt_insert_block(self, b, new_start_time, start_time_idx):
         # set duration to be exact multiple of time resolution
-        duration_indices = np.int(np.ceil(
+        duration_indices = int(np.floor(
             float(b.duration / self.time_resolution)))
         b.duration = duration_indices * self.time_resolution
 
@@ -874,7 +877,7 @@ class PriorityScheduler(Scheduler):
         # tweak durations to exact multiple of time resolution
         for block in (tb_before, tb_after):
             if block is not None:
-                block.duration = self.time_resolution * np.int(
+                block.duration = self.time_resolution * int(
                     np.ceil(float(block.duration / self.time_resolution))
                 )
 
@@ -891,7 +894,7 @@ class PriorityScheduler(Scheduler):
             ob_offset = 2 if tb_before_already_exists else 1
             previous_ob = self.schedule.slots[slot_index - ob_offset]
             if tb_before:
-                transition_indices = np.int(tb_before.duration / self.time_resolution)
+                transition_indices = int(tb_before.duration / self.time_resolution)
             else:
                 transition_indices = 0
 
@@ -906,7 +909,7 @@ class PriorityScheduler(Scheduler):
             next_ob = self.schedule.slots[slot_index + slot_offset].block
             end_idx = start_time_idx + duration_indices
             if tb_after:
-                end_idx += np.int(tb_after.duration/self.time_resolution)
+                end_idx += int(tb_after.duration / self.time_resolution)
                 if end_idx >= next_ob.start_idx:
                     # cannot schedule
                     return False
